#!/usr/bin/env python
# coding: utf-8

# cpapp.py

import os
import cherrypy
import http_root
from lib.constants import APPDIR, INIPATH, LOGDIR, HTTPROOTDIR


def get_app():
    """
    Gibt die CherryPy-Application zurück.
    
    Diese kann auch direkt als WSGI-Application genutzt werden. 
    Dabei werden auch die Einstellungen gesetzt.
    """
    
    # Applikation
    app = cherrypy.tree.mount(http_root, config = INIPATH)
    cherrypy.config.update(INIPATH)
    
    # Logfile
    error_logfile_path = os.path.join(LOGDIR, "cherrypy_error.log")

    # cherrypy.config
    config = {
        #'environment': 'production',
        #'log.screen': False,
        'log.error_file': error_logfile_path,
        #'show_tracebacks': False,
        #'engine.autoreload_on': False,
        "tools.staticdir.root": HTTPROOTDIR,
    }
    cherrypy.config.update(config)
    
    # Rückgabe der Applikation
    return app


def get_wsgi_app():
    """
    Gibt die WSGI-Application (bereits fertig konfiguriert) zurück
    """

    # Anwendung vorkonfiguriert holen
    app = get_app()

    # Konfiguration anpassen
    config = {
        "environment": "embedded",
        "log.screen": False,
        "show_tracebacks": False,
        "engine.autoreload_on": False,
        "tools.email_tracebacks.on": True,
    }
    cherrypy.config.update(config)

    # Rückgabe
    return app


def main():
    
    # Anwendung "lokal" starten
    app = get_app()
    cherrypy.quickstart(app)


if __name__ == "__main__":
    main()

